# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccessPointArgs', 'AccessPoint']

@pulumi.input_type
class AccessPointArgs:
    def __init__(__self__, *,
                 access_point_name: pulumi.Input[builtins.str],
                 bucket: pulumi.Input[builtins.str],
                 network_origin: pulumi.Input[builtins.str],
                 public_access_block_configuration: Optional[pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs']] = None,
                 vpc_configuration: Optional[pulumi.Input['AccessPointVpcConfigurationArgs']] = None):
        """
        The set of arguments for constructing a AccessPoint resource.
        :param pulumi.Input[builtins.str] access_point_name: The name of the access point
        :param pulumi.Input[builtins.str] bucket: The Bucket to which the current access point belongs.
        :param pulumi.Input[builtins.str] network_origin: Access point network source. The valid values are as follows: 
               - vpc: only the specified VPC ID can be used to access the access point.
               - internet: the access point can be accessed through both external and internal Endpoint.
        :param pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs'] public_access_block_configuration: Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        :param pulumi.Input['AccessPointVpcConfigurationArgs'] vpc_configuration: If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        pulumi.set(__self__, "access_point_name", access_point_name)
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "network_origin", network_origin)
        if public_access_block_configuration is not None:
            pulumi.set(__self__, "public_access_block_configuration", public_access_block_configuration)
        if vpc_configuration is not None:
            pulumi.set(__self__, "vpc_configuration", vpc_configuration)

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the access point
        """
        return pulumi.get(self, "access_point_name")

    @access_point_name.setter
    def access_point_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "access_point_name", value)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[builtins.str]:
        """
        The Bucket to which the current access point belongs.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="networkOrigin")
    def network_origin(self) -> pulumi.Input[builtins.str]:
        """
        Access point network source. The valid values are as follows: 
        - vpc: only the specified VPC ID can be used to access the access point.
        - internet: the access point can be accessed through both external and internal Endpoint.
        """
        return pulumi.get(self, "network_origin")

    @network_origin.setter
    def network_origin(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "network_origin", value)

    @property
    @pulumi.getter(name="publicAccessBlockConfiguration")
    def public_access_block_configuration(self) -> Optional[pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs']]:
        """
        Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        """
        return pulumi.get(self, "public_access_block_configuration")

    @public_access_block_configuration.setter
    def public_access_block_configuration(self, value: Optional[pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs']]):
        pulumi.set(self, "public_access_block_configuration", value)

    @property
    @pulumi.getter(name="vpcConfiguration")
    def vpc_configuration(self) -> Optional[pulumi.Input['AccessPointVpcConfigurationArgs']]:
        """
        If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        return pulumi.get(self, "vpc_configuration")

    @vpc_configuration.setter
    def vpc_configuration(self, value: Optional[pulumi.Input['AccessPointVpcConfigurationArgs']]):
        pulumi.set(self, "vpc_configuration", value)


@pulumi.input_type
class _AccessPointState:
    def __init__(__self__, *,
                 access_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 network_origin: Optional[pulumi.Input[builtins.str]] = None,
                 public_access_block_configuration: Optional[pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_configuration: Optional[pulumi.Input['AccessPointVpcConfigurationArgs']] = None):
        """
        Input properties used for looking up and filtering AccessPoint resources.
        :param pulumi.Input[builtins.str] access_point_name: The name of the access point
        :param pulumi.Input[builtins.str] bucket: The Bucket to which the current access point belongs.
        :param pulumi.Input[builtins.str] network_origin: Access point network source. The valid values are as follows: 
               - vpc: only the specified VPC ID can be used to access the access point.
               - internet: the access point can be accessed through both external and internal Endpoint.
        :param pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs'] public_access_block_configuration: Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input['AccessPointVpcConfigurationArgs'] vpc_configuration: If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        if access_point_name is not None:
            pulumi.set(__self__, "access_point_name", access_point_name)
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if network_origin is not None:
            pulumi.set(__self__, "network_origin", network_origin)
        if public_access_block_configuration is not None:
            pulumi.set(__self__, "public_access_block_configuration", public_access_block_configuration)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_configuration is not None:
            pulumi.set(__self__, "vpc_configuration", vpc_configuration)

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the access point
        """
        return pulumi.get(self, "access_point_name")

    @access_point_name.setter
    def access_point_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_point_name", value)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Bucket to which the current access point belongs.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="networkOrigin")
    def network_origin(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Access point network source. The valid values are as follows: 
        - vpc: only the specified VPC ID can be used to access the access point.
        - internet: the access point can be accessed through both external and internal Endpoint.
        """
        return pulumi.get(self, "network_origin")

    @network_origin.setter
    def network_origin(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_origin", value)

    @property
    @pulumi.getter(name="publicAccessBlockConfiguration")
    def public_access_block_configuration(self) -> Optional[pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs']]:
        """
        Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        """
        return pulumi.get(self, "public_access_block_configuration")

    @public_access_block_configuration.setter
    def public_access_block_configuration(self, value: Optional[pulumi.Input['AccessPointPublicAccessBlockConfigurationArgs']]):
        pulumi.set(self, "public_access_block_configuration", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcConfiguration")
    def vpc_configuration(self) -> Optional[pulumi.Input['AccessPointVpcConfigurationArgs']]:
        """
        If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        return pulumi.get(self, "vpc_configuration")

    @vpc_configuration.setter
    def vpc_configuration(self, value: Optional[pulumi.Input['AccessPointVpcConfigurationArgs']]):
        pulumi.set(self, "vpc_configuration", value)


@pulumi.type_token("alicloud:oss/accessPoint:AccessPoint")
class AccessPoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 network_origin: Optional[pulumi.Input[builtins.str]] = None,
                 public_access_block_configuration: Optional[pulumi.Input[Union['AccessPointPublicAccessBlockConfigurationArgs', 'AccessPointPublicAccessBlockConfigurationArgsDict']]] = None,
                 vpc_configuration: Optional[pulumi.Input[Union['AccessPointVpcConfigurationArgs', 'AccessPointVpcConfigurationArgsDict']]] = None,
                 __props__=None):
        """
        Provides a OSS Access Point resource.

        You can create multiple Access points for buckets and configure different Access control permissions and network control policies for different Access points.

        For information about OSS Access Point and how to use it, see [What is Access Point](https://www.alibabacloud.com/help/en/oss/developer-reference/createaccesspoint).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        create_bucket = alicloud.oss.Bucket("CreateBucket", storage_class="Standard")
        default = alicloud.oss.AccessPoint("default",
            access_point_name=name,
            bucket=create_bucket.bucket,
            vpc_configuration={
                "vpc_id": "vpc-abcexample",
            },
            network_origin="vpc",
            public_access_block_configuration={
                "block_public_access": True,
            })
        ```

        ## Import

        OSS Access Point can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/accessPoint:AccessPoint example <bucket>:<access_point_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_point_name: The name of the access point
        :param pulumi.Input[builtins.str] bucket: The Bucket to which the current access point belongs.
        :param pulumi.Input[builtins.str] network_origin: Access point network source. The valid values are as follows: 
               - vpc: only the specified VPC ID can be used to access the access point.
               - internet: the access point can be accessed through both external and internal Endpoint.
        :param pulumi.Input[Union['AccessPointPublicAccessBlockConfigurationArgs', 'AccessPointPublicAccessBlockConfigurationArgsDict']] public_access_block_configuration: Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        :param pulumi.Input[Union['AccessPointVpcConfigurationArgs', 'AccessPointVpcConfigurationArgsDict']] vpc_configuration: If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccessPointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a OSS Access Point resource.

        You can create multiple Access points for buckets and configure different Access control permissions and network control policies for different Access points.

        For information about OSS Access Point and how to use it, see [What is Access Point](https://www.alibabacloud.com/help/en/oss/developer-reference/createaccesspoint).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        create_bucket = alicloud.oss.Bucket("CreateBucket", storage_class="Standard")
        default = alicloud.oss.AccessPoint("default",
            access_point_name=name,
            bucket=create_bucket.bucket,
            vpc_configuration={
                "vpc_id": "vpc-abcexample",
            },
            network_origin="vpc",
            public_access_block_configuration={
                "block_public_access": True,
            })
        ```

        ## Import

        OSS Access Point can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/accessPoint:AccessPoint example <bucket>:<access_point_name>
        ```

        :param str resource_name: The name of the resource.
        :param AccessPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccessPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 bucket: Optional[pulumi.Input[builtins.str]] = None,
                 network_origin: Optional[pulumi.Input[builtins.str]] = None,
                 public_access_block_configuration: Optional[pulumi.Input[Union['AccessPointPublicAccessBlockConfigurationArgs', 'AccessPointPublicAccessBlockConfigurationArgsDict']]] = None,
                 vpc_configuration: Optional[pulumi.Input[Union['AccessPointVpcConfigurationArgs', 'AccessPointVpcConfigurationArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccessPointArgs.__new__(AccessPointArgs)

            if access_point_name is None and not opts.urn:
                raise TypeError("Missing required property 'access_point_name'")
            __props__.__dict__["access_point_name"] = access_point_name
            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            if network_origin is None and not opts.urn:
                raise TypeError("Missing required property 'network_origin'")
            __props__.__dict__["network_origin"] = network_origin
            __props__.__dict__["public_access_block_configuration"] = public_access_block_configuration
            __props__.__dict__["vpc_configuration"] = vpc_configuration
            __props__.__dict__["status"] = None
        super(AccessPoint, __self__).__init__(
            'alicloud:oss/accessPoint:AccessPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_point_name: Optional[pulumi.Input[builtins.str]] = None,
            bucket: Optional[pulumi.Input[builtins.str]] = None,
            network_origin: Optional[pulumi.Input[builtins.str]] = None,
            public_access_block_configuration: Optional[pulumi.Input[Union['AccessPointPublicAccessBlockConfigurationArgs', 'AccessPointPublicAccessBlockConfigurationArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            vpc_configuration: Optional[pulumi.Input[Union['AccessPointVpcConfigurationArgs', 'AccessPointVpcConfigurationArgsDict']]] = None) -> 'AccessPoint':
        """
        Get an existing AccessPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_point_name: The name of the access point
        :param pulumi.Input[builtins.str] bucket: The Bucket to which the current access point belongs.
        :param pulumi.Input[builtins.str] network_origin: Access point network source. The valid values are as follows: 
               - vpc: only the specified VPC ID can be used to access the access point.
               - internet: the access point can be accessed through both external and internal Endpoint.
        :param pulumi.Input[Union['AccessPointPublicAccessBlockConfigurationArgs', 'AccessPointPublicAccessBlockConfigurationArgsDict']] public_access_block_configuration: Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[Union['AccessPointVpcConfigurationArgs', 'AccessPointVpcConfigurationArgsDict']] vpc_configuration: If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccessPointState.__new__(_AccessPointState)

        __props__.__dict__["access_point_name"] = access_point_name
        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["network_origin"] = network_origin
        __props__.__dict__["public_access_block_configuration"] = public_access_block_configuration
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_configuration"] = vpc_configuration
        return AccessPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the access point
        """
        return pulumi.get(self, "access_point_name")

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[builtins.str]:
        """
        The Bucket to which the current access point belongs.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="networkOrigin")
    def network_origin(self) -> pulumi.Output[builtins.str]:
        """
        Access point network source. The valid values are as follows: 
        - vpc: only the specified VPC ID can be used to access the access point.
        - internet: the access point can be accessed through both external and internal Endpoint.
        """
        return pulumi.get(self, "network_origin")

    @property
    @pulumi.getter(name="publicAccessBlockConfiguration")
    def public_access_block_configuration(self) -> pulumi.Output[Optional['outputs.AccessPointPublicAccessBlockConfiguration']]:
        """
        Configuration of Access Point Blocking Public Access See `public_access_block_configuration` below.
        """
        return pulumi.get(self, "public_access_block_configuration")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcConfiguration")
    def vpc_configuration(self) -> pulumi.Output[Optional['outputs.AccessPointVpcConfiguration']]:
        """
        If the Network Origin is vpc, the VPC source information is saved here. See `vpc_configuration` below.
        """
        return pulumi.get(self, "vpc_configuration")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ScimServerCredentialArgs', 'ScimServerCredential']

@pulumi.input_type
class ScimServerCredentialArgs:
    def __init__(__self__, *,
                 directory_id: pulumi.Input[builtins.str],
                 credential_secret_file: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ScimServerCredential resource.
        :param pulumi.Input[builtins.str] directory_id: The ID of the Directory.
        :param pulumi.Input[builtins.str] credential_secret_file: The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[builtins.str] status: The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        pulumi.set(__self__, "directory_id", directory_id)
        if credential_secret_file is not None:
            pulumi.set(__self__, "credential_secret_file", credential_secret_file)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @directory_id.setter
    def directory_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "directory_id", value)

    @property
    @pulumi.getter(name="credentialSecretFile")
    def credential_secret_file(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "credential_secret_file")

    @credential_secret_file.setter
    def credential_secret_file(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "credential_secret_file", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ScimServerCredentialState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 credential_id: Optional[pulumi.Input[builtins.str]] = None,
                 credential_secret_file: Optional[pulumi.Input[builtins.str]] = None,
                 credential_type: Optional[pulumi.Input[builtins.str]] = None,
                 directory_id: Optional[pulumi.Input[builtins.str]] = None,
                 expire_time: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ScimServerCredential resources.
        :param pulumi.Input[builtins.str] create_time: (Available since v1.245.0) The time when the SCIM credential was created.
        :param pulumi.Input[builtins.str] credential_id: The ID of the SCIM credential.
        :param pulumi.Input[builtins.str] credential_secret_file: The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[builtins.str] credential_type: (Available since v1.245.0) The type of the SCIM credential.
        :param pulumi.Input[builtins.str] directory_id: The ID of the Directory.
        :param pulumi.Input[builtins.str] expire_time: (Available since v1.245.0) The time when the SCIM credential expires.
        :param pulumi.Input[builtins.str] status: The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if credential_id is not None:
            pulumi.set(__self__, "credential_id", credential_id)
        if credential_secret_file is not None:
            pulumi.set(__self__, "credential_secret_file", credential_secret_file)
        if credential_type is not None:
            pulumi.set(__self__, "credential_type", credential_type)
        if directory_id is not None:
            pulumi.set(__self__, "directory_id", directory_id)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available since v1.245.0) The time when the SCIM credential was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="credentialId")
    def credential_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the SCIM credential.
        """
        return pulumi.get(self, "credential_id")

    @credential_id.setter
    def credential_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "credential_id", value)

    @property
    @pulumi.getter(name="credentialSecretFile")
    def credential_secret_file(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "credential_secret_file")

    @credential_secret_file.setter
    def credential_secret_file(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "credential_secret_file", value)

    @property
    @pulumi.getter(name="credentialType")
    def credential_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available since v1.245.0) The type of the SCIM credential.
        """
        return pulumi.get(self, "credential_type")

    @credential_type.setter
    def credential_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "credential_type", value)

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @directory_id.setter
    def directory_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "directory_id", value)

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available since v1.245.0) The time when the SCIM credential expires.
        """
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expire_time", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:cloudsso/scimServerCredential:ScimServerCredential")
class ScimServerCredential(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credential_secret_file: Optional[pulumi.Input[builtins.str]] = None,
                 directory_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud SSO SCIM Server Credential resource.

        For information about Cloud SSO SCIM Server Credential and how to use it, see [What is Cloud SSO SCIM Server Credential](https://www.alibabacloud.com/help/en/cloudsso/latest/api-cloudsso-2021-05-15-createscimservercredential).

        > **NOTE:** Available since v1.138.0.

        > **NOTE:** Cloud SSO Only Support `cn-shanghai` And `us-west-1` Region

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.cloudsso.get_directories()
        default_scim_server_credential = alicloud.cloudsso.ScimServerCredential("default",
            directory_id=default.directories[0].id,
            credential_secret_file="./credential_secret_file.txt")
        ```

        ## Import

        Cloud SSO SCIM Server Credential can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudsso/scimServerCredential:ScimServerCredential example <directory_id>:<credential_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] credential_secret_file: The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[builtins.str] directory_id: The ID of the Directory.
        :param pulumi.Input[builtins.str] status: The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ScimServerCredentialArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud SSO SCIM Server Credential resource.

        For information about Cloud SSO SCIM Server Credential and how to use it, see [What is Cloud SSO SCIM Server Credential](https://www.alibabacloud.com/help/en/cloudsso/latest/api-cloudsso-2021-05-15-createscimservercredential).

        > **NOTE:** Available since v1.138.0.

        > **NOTE:** Cloud SSO Only Support `cn-shanghai` And `us-west-1` Region

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.cloudsso.get_directories()
        default_scim_server_credential = alicloud.cloudsso.ScimServerCredential("default",
            directory_id=default.directories[0].id,
            credential_secret_file="./credential_secret_file.txt")
        ```

        ## Import

        Cloud SSO SCIM Server Credential can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudsso/scimServerCredential:ScimServerCredential example <directory_id>:<credential_id>
        ```

        :param str resource_name: The name of the resource.
        :param ScimServerCredentialArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ScimServerCredentialArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 credential_secret_file: Optional[pulumi.Input[builtins.str]] = None,
                 directory_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ScimServerCredentialArgs.__new__(ScimServerCredentialArgs)

            __props__.__dict__["credential_secret_file"] = credential_secret_file
            if directory_id is None and not opts.urn:
                raise TypeError("Missing required property 'directory_id'")
            __props__.__dict__["directory_id"] = directory_id
            __props__.__dict__["status"] = status
            __props__.__dict__["create_time"] = None
            __props__.__dict__["credential_id"] = None
            __props__.__dict__["credential_type"] = None
            __props__.__dict__["expire_time"] = None
        super(ScimServerCredential, __self__).__init__(
            'alicloud:cloudsso/scimServerCredential:ScimServerCredential',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            credential_id: Optional[pulumi.Input[builtins.str]] = None,
            credential_secret_file: Optional[pulumi.Input[builtins.str]] = None,
            credential_type: Optional[pulumi.Input[builtins.str]] = None,
            directory_id: Optional[pulumi.Input[builtins.str]] = None,
            expire_time: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ScimServerCredential':
        """
        Get an existing ScimServerCredential resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: (Available since v1.245.0) The time when the SCIM credential was created.
        :param pulumi.Input[builtins.str] credential_id: The ID of the SCIM credential.
        :param pulumi.Input[builtins.str] credential_secret_file: The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[builtins.str] credential_type: (Available since v1.245.0) The type of the SCIM credential.
        :param pulumi.Input[builtins.str] directory_id: The ID of the Directory.
        :param pulumi.Input[builtins.str] expire_time: (Available since v1.245.0) The time when the SCIM credential expires.
        :param pulumi.Input[builtins.str] status: The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ScimServerCredentialState.__new__(_ScimServerCredentialState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["credential_id"] = credential_id
        __props__.__dict__["credential_secret_file"] = credential_secret_file
        __props__.__dict__["credential_type"] = credential_type
        __props__.__dict__["directory_id"] = directory_id
        __props__.__dict__["expire_time"] = expire_time
        __props__.__dict__["status"] = status
        return ScimServerCredential(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        (Available since v1.245.0) The time when the SCIM credential was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="credentialId")
    def credential_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the SCIM credential.
        """
        return pulumi.get(self, "credential_id")

    @property
    @pulumi.getter(name="credentialSecretFile")
    def credential_secret_file(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of file that can save Credential ID and Credential Secret. Strongly suggest you to specified it when you creating credential, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "credential_secret_file")

    @property
    @pulumi.getter(name="credentialType")
    def credential_type(self) -> pulumi.Output[builtins.str]:
        """
        (Available since v1.245.0) The type of the SCIM credential.
        """
        return pulumi.get(self, "credential_type")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the Directory.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> pulumi.Output[builtins.str]:
        """
        (Available since v1.245.0) The time when the SCIM credential expires.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the SCIM Server Credential. Valid values: `Enabled`, `Disabled`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ResourceArgs', 'Resource']

@pulumi.input_type
class ResourceArgs:
    def __init__(__self__, *,
                 product: pulumi.Input[builtins.str],
                 resource_code: pulumi.Input[builtins.str],
                 desire_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Resource resource.
        :param pulumi.Input[builtins.str] product: The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_code: Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] desire_attributes: Resource attributes specified when a user creates or updates a resource.
        :param pulumi.Input[builtins.str] resource_id: If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        pulumi.set(__self__, "product", product)
        pulumi.set(__self__, "resource_code", resource_code)
        if desire_attributes is not None:
            pulumi.set(__self__, "desire_attributes", desire_attributes)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)

    @property
    @pulumi.getter
    def product(self) -> pulumi.Input[builtins.str]:
        """
        The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        """
        return pulumi.get(self, "product")

    @product.setter
    def product(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "product", value)

    @property
    @pulumi.getter(name="resourceCode")
    def resource_code(self) -> pulumi.Input[builtins.str]:
        """
        Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        """
        return pulumi.get(self, "resource_code")

    @resource_code.setter
    def resource_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_code", value)

    @property
    @pulumi.getter(name="desireAttributes")
    def desire_attributes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource attributes specified when a user creates or updates a resource.
        """
        return pulumi.get(self, "desire_attributes")

    @desire_attributes.setter
    def desire_attributes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "desire_attributes", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)


@pulumi.input_type
class _ResourceState:
    def __init__(__self__, *,
                 desire_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 product: Optional[pulumi.Input[builtins.str]] = None,
                 resource_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 resource_code: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Resource resources.
        :param pulumi.Input[builtins.str] desire_attributes: Resource attributes specified when a user creates or updates a resource.
        :param pulumi.Input[builtins.str] product: The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_attributes: The collection of properties for the resource.
        :param pulumi.Input[builtins.str] resource_code: Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_id: If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        if desire_attributes is not None:
            pulumi.set(__self__, "desire_attributes", desire_attributes)
        if product is not None:
            pulumi.set(__self__, "product", product)
        if resource_attributes is not None:
            pulumi.set(__self__, "resource_attributes", resource_attributes)
        if resource_code is not None:
            pulumi.set(__self__, "resource_code", resource_code)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)

    @property
    @pulumi.getter(name="desireAttributes")
    def desire_attributes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource attributes specified when a user creates or updates a resource.
        """
        return pulumi.get(self, "desire_attributes")

    @desire_attributes.setter
    def desire_attributes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "desire_attributes", value)

    @property
    @pulumi.getter
    def product(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        """
        return pulumi.get(self, "product")

    @product.setter
    def product(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "product", value)

    @property
    @pulumi.getter(name="resourceAttributes")
    def resource_attributes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The collection of properties for the resource.
        """
        return pulumi.get(self, "resource_attributes")

    @resource_attributes.setter
    def resource_attributes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_attributes", value)

    @property
    @pulumi.getter(name="resourceCode")
    def resource_code(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        """
        return pulumi.get(self, "resource_code")

    @resource_code.setter
    def resource_code(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_code", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)


@pulumi.type_token("alicloud:cloudcontrol/resource:Resource")
class Resource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 desire_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 product: Optional[pulumi.Input[builtins.str]] = None,
                 resource_code: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud Control Resource resource.

        For information about Cloud Control Resource and how to use it, see [What is Resource](https://next.api.aliyun.com/document/cloudcontrol/2022-08-30/GetResourceType).

        > **NOTE:** Available since v1.241.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        mq_instance = alicloud.cloudcontrol.Resource("mq_instance",
            desire_attributes=json.dumps({
                "InstanceName": "terraform-example-ons-instance",
            }),
            product="Ons",
            resource_code="Instance")
        default = alicloud.cloudcontrol.Resource("default",
            product="Ons",
            resource_code="Instance::Topic",
            resource_id=mq_instance.resource_id,
            desire_attributes=pulumi.Output.json_dumps({
                "InstanceId": mq_instance.resource_id,
                "TopicName": "terraform-example-ons-topic",
                "MessageType": "1",
            }))
        ```

        ## Import

        Cloud Control Resource can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudcontrol/resource:Resource example <provider>:<product>:<resource_code>:<resource_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] desire_attributes: Resource attributes specified when a user creates or updates a resource.
        :param pulumi.Input[builtins.str] product: The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_code: Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_id: If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ResourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Control Resource resource.

        For information about Cloud Control Resource and how to use it, see [What is Resource](https://next.api.aliyun.com/document/cloudcontrol/2022-08-30/GetResourceType).

        > **NOTE:** Available since v1.241.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        mq_instance = alicloud.cloudcontrol.Resource("mq_instance",
            desire_attributes=json.dumps({
                "InstanceName": "terraform-example-ons-instance",
            }),
            product="Ons",
            resource_code="Instance")
        default = alicloud.cloudcontrol.Resource("default",
            product="Ons",
            resource_code="Instance::Topic",
            resource_id=mq_instance.resource_id,
            desire_attributes=pulumi.Output.json_dumps({
                "InstanceId": mq_instance.resource_id,
                "TopicName": "terraform-example-ons-topic",
                "MessageType": "1",
            }))
        ```

        ## Import

        Cloud Control Resource can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudcontrol/resource:Resource example <provider>:<product>:<resource_code>:<resource_id>
        ```

        :param str resource_name: The name of the resource.
        :param ResourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ResourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 desire_attributes: Optional[pulumi.Input[builtins.str]] = None,
                 product: Optional[pulumi.Input[builtins.str]] = None,
                 resource_code: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ResourceArgs.__new__(ResourceArgs)

            __props__.__dict__["desire_attributes"] = None if desire_attributes is None else pulumi.Output.secret(desire_attributes)
            if product is None and not opts.urn:
                raise TypeError("Missing required property 'product'")
            __props__.__dict__["product"] = product
            if resource_code is None and not opts.urn:
                raise TypeError("Missing required property 'resource_code'")
            __props__.__dict__["resource_code"] = resource_code
            __props__.__dict__["resource_id"] = resource_id
            __props__.__dict__["resource_attributes"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["desireAttributes"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Resource, __self__).__init__(
            'alicloud:cloudcontrol/resource:Resource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            desire_attributes: Optional[pulumi.Input[builtins.str]] = None,
            product: Optional[pulumi.Input[builtins.str]] = None,
            resource_attributes: Optional[pulumi.Input[builtins.str]] = None,
            resource_code: Optional[pulumi.Input[builtins.str]] = None,
            resource_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Resource':
        """
        Get an existing Resource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] desire_attributes: Resource attributes specified when a user creates or updates a resource.
        :param pulumi.Input[builtins.str] product: The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_attributes: The collection of properties for the resource.
        :param pulumi.Input[builtins.str] resource_code: Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        :param pulumi.Input[builtins.str] resource_id: If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ResourceState.__new__(_ResourceState)

        __props__.__dict__["desire_attributes"] = desire_attributes
        __props__.__dict__["product"] = product
        __props__.__dict__["resource_attributes"] = resource_attributes
        __props__.__dict__["resource_code"] = resource_code
        __props__.__dict__["resource_id"] = resource_id
        return Resource(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="desireAttributes")
    def desire_attributes(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Resource attributes specified when a user creates or updates a resource.
        """
        return pulumi.get(self, "desire_attributes")

    @property
    @pulumi.getter
    def product(self) -> pulumi.Output[builtins.str]:
        """
        The product Code represents the product to be operated. Currently supported products and resources can be queried at the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        """
        return pulumi.get(self, "product")

    @property
    @pulumi.getter(name="resourceAttributes")
    def resource_attributes(self) -> pulumi.Output[builtins.str]:
        """
        The collection of properties for the resource.
        """
        return pulumi.get(self, "resource_attributes")

    @property
    @pulumi.getter(name="resourceCode")
    def resource_code(self) -> pulumi.Output[builtins.str]:
        """
        Resource Code, if there is a parent resource, split with `::`, such as VPC::VSwitch. The supported resource Code can be obtained from the following link: [supported-services-and-resource-types](https://help.aliyun.com/zh/cloud-control-api/product-overview/supported-services-and-resource-types).
        """
        return pulumi.get(self, "resource_code")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[builtins.str]:
        """
        If there is a parent resource, you need to enter the id of the parent resource, for example, in the VPC::VSwtich resource, you need to enter the id of the VPC: vpc-dexadfe3r4ad. If there are more than one level of parent resources, you need to use `:` to split.
        """
        return pulumi.get(self, "resource_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SecurityPreferenceArgs', 'SecurityPreference']

@pulumi.input_type
class SecurityPreferenceArgs:
    def __init__(__self__, *,
                 allow_user_to_change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_login_with_passkey: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_access_keys: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_mfa_devices: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_personal_ding_talk: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_save_mfa_ticket: Optional[pulumi.Input[builtins.bool]] = None,
                 enforce_mfa_for_login: Optional[pulumi.Input[builtins.bool]] = None,
                 login_network_masks: Optional[pulumi.Input[builtins.str]] = None,
                 login_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 mfa_operation_for_login: Optional[pulumi.Input[builtins.str]] = None,
                 operation_for_risk_login: Optional[pulumi.Input[builtins.str]] = None,
                 verification_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a SecurityPreference resource.
        :param pulumi.Input[builtins.bool] allow_user_to_change_password: Whether to allow RAM users to manage their own passwords. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_login_with_passkey: Whether to allow RAM users to log on using a passkey. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_access_keys: Whether to allow RAM users to manage their own access keys. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_mfa_devices: Whether to allow RAM users to manage multi-factor authentication devices. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_personal_ding_talk: Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] enable_save_mfa_ticket: Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] enforce_mfa_for_login: Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
               Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        :param pulumi.Input[builtins.str] login_network_masks: The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
               - If the mask is specified, RAM users can only log on from the specified IP address.
               - If you do not specify any mask, the login console function will apply to the entire network.
               
               When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.
               
               Configure a maximum of 40 logon masks, with a total length of 512 characters.
        :param pulumi.Input[builtins.int] login_session_duration: The validity period of the logon session of RAM users.
               Valid values: 1 to 24. Unit: hours.
               Default value: 6.
        :param pulumi.Input[builtins.str] mfa_operation_for_login: MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
               - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
               - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
               - adaptive: Used only during abnormal login.
        :param pulumi.Input[builtins.str] operation_for_risk_login: Whether MFA is verified twice during abnormal logon. Value:
               - autonomous (default): Skip, do not force binding.
               - enforceVerify: Force binding validation.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] verification_types: Means of multi-factor authentication. Value:
               - sms: secure phone.
               - email: Secure mailbox.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if allow_user_to_change_password is not None:
            pulumi.set(__self__, "allow_user_to_change_password", allow_user_to_change_password)
        if allow_user_to_login_with_passkey is not None:
            pulumi.set(__self__, "allow_user_to_login_with_passkey", allow_user_to_login_with_passkey)
        if allow_user_to_manage_access_keys is not None:
            pulumi.set(__self__, "allow_user_to_manage_access_keys", allow_user_to_manage_access_keys)
        if allow_user_to_manage_mfa_devices is not None:
            pulumi.set(__self__, "allow_user_to_manage_mfa_devices", allow_user_to_manage_mfa_devices)
        if allow_user_to_manage_personal_ding_talk is not None:
            pulumi.set(__self__, "allow_user_to_manage_personal_ding_talk", allow_user_to_manage_personal_ding_talk)
        if enable_save_mfa_ticket is not None:
            pulumi.set(__self__, "enable_save_mfa_ticket", enable_save_mfa_ticket)
        if enforce_mfa_for_login is not None:
            pulumi.set(__self__, "enforce_mfa_for_login", enforce_mfa_for_login)
        if login_network_masks is not None:
            pulumi.set(__self__, "login_network_masks", login_network_masks)
        if login_session_duration is not None:
            pulumi.set(__self__, "login_session_duration", login_session_duration)
        if mfa_operation_for_login is not None:
            pulumi.set(__self__, "mfa_operation_for_login", mfa_operation_for_login)
        if operation_for_risk_login is not None:
            pulumi.set(__self__, "operation_for_risk_login", operation_for_risk_login)
        if verification_types is not None:
            pulumi.set(__self__, "verification_types", verification_types)

    @property
    @pulumi.getter(name="allowUserToChangePassword")
    def allow_user_to_change_password(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to manage their own passwords. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_change_password")

    @allow_user_to_change_password.setter
    def allow_user_to_change_password(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_change_password", value)

    @property
    @pulumi.getter(name="allowUserToLoginWithPasskey")
    def allow_user_to_login_with_passkey(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to log on using a passkey. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_login_with_passkey")

    @allow_user_to_login_with_passkey.setter
    def allow_user_to_login_with_passkey(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_login_with_passkey", value)

    @property
    @pulumi.getter(name="allowUserToManageAccessKeys")
    def allow_user_to_manage_access_keys(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to manage their own access keys. Value:
        - true: Allow.
        - false (default): Not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_access_keys")

    @allow_user_to_manage_access_keys.setter
    def allow_user_to_manage_access_keys(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_manage_access_keys", value)

    @property
    @pulumi.getter(name="allowUserToManageMfaDevices")
    def allow_user_to_manage_mfa_devices(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to manage multi-factor authentication devices. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_mfa_devices")

    @allow_user_to_manage_mfa_devices.setter
    def allow_user_to_manage_mfa_devices(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_manage_mfa_devices", value)

    @property
    @pulumi.getter(name="allowUserToManagePersonalDingTalk")
    def allow_user_to_manage_personal_ding_talk(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_personal_ding_talk")

    @allow_user_to_manage_personal_ding_talk.setter
    def allow_user_to_manage_personal_ding_talk(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_manage_personal_ding_talk", value)

    @property
    @pulumi.getter(name="enableSaveMfaTicket")
    def enable_save_mfa_ticket(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
        - true: Allow.
        - false (default): Not allowed.
        """
        return pulumi.get(self, "enable_save_mfa_ticket")

    @enable_save_mfa_ticket.setter
    def enable_save_mfa_ticket(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_save_mfa_ticket", value)

    @property
    @pulumi.getter(name="enforceMfaForLogin")
    def enforce_mfa_for_login(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
        Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        """
        return pulumi.get(self, "enforce_mfa_for_login")

    @enforce_mfa_for_login.setter
    def enforce_mfa_for_login(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enforce_mfa_for_login", value)

    @property
    @pulumi.getter(name="loginNetworkMasks")
    def login_network_masks(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
        - If the mask is specified, RAM users can only log on from the specified IP address.
        - If you do not specify any mask, the login console function will apply to the entire network.

        When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.

        Configure a maximum of 40 logon masks, with a total length of 512 characters.
        """
        return pulumi.get(self, "login_network_masks")

    @login_network_masks.setter
    def login_network_masks(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login_network_masks", value)

    @property
    @pulumi.getter(name="loginSessionDuration")
    def login_session_duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The validity period of the logon session of RAM users.
        Valid values: 1 to 24. Unit: hours.
        Default value: 6.
        """
        return pulumi.get(self, "login_session_duration")

    @login_session_duration.setter
    def login_session_duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "login_session_duration", value)

    @property
    @pulumi.getter(name="mfaOperationForLogin")
    def mfa_operation_for_login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
        - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
        - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
        - adaptive: Used only during abnormal login.
        """
        return pulumi.get(self, "mfa_operation_for_login")

    @mfa_operation_for_login.setter
    def mfa_operation_for_login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mfa_operation_for_login", value)

    @property
    @pulumi.getter(name="operationForRiskLogin")
    def operation_for_risk_login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether MFA is verified twice during abnormal logon. Value:
        - autonomous (default): Skip, do not force binding.
        - enforceVerify: Force binding validation.
        """
        return pulumi.get(self, "operation_for_risk_login")

    @operation_for_risk_login.setter
    def operation_for_risk_login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "operation_for_risk_login", value)

    @property
    @pulumi.getter(name="verificationTypes")
    def verification_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Means of multi-factor authentication. Value:
        - sms: secure phone.
        - email: Secure mailbox.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "verification_types")

    @verification_types.setter
    def verification_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "verification_types", value)


@pulumi.input_type
class _SecurityPreferenceState:
    def __init__(__self__, *,
                 allow_user_to_change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_login_with_passkey: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_access_keys: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_mfa_devices: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_personal_ding_talk: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_save_mfa_ticket: Optional[pulumi.Input[builtins.bool]] = None,
                 enforce_mfa_for_login: Optional[pulumi.Input[builtins.bool]] = None,
                 login_network_masks: Optional[pulumi.Input[builtins.str]] = None,
                 login_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 mfa_operation_for_login: Optional[pulumi.Input[builtins.str]] = None,
                 operation_for_risk_login: Optional[pulumi.Input[builtins.str]] = None,
                 verification_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SecurityPreference resources.
        :param pulumi.Input[builtins.bool] allow_user_to_change_password: Whether to allow RAM users to manage their own passwords. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_login_with_passkey: Whether to allow RAM users to log on using a passkey. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_access_keys: Whether to allow RAM users to manage their own access keys. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_mfa_devices: Whether to allow RAM users to manage multi-factor authentication devices. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_personal_ding_talk: Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] enable_save_mfa_ticket: Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] enforce_mfa_for_login: Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
               Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        :param pulumi.Input[builtins.str] login_network_masks: The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
               - If the mask is specified, RAM users can only log on from the specified IP address.
               - If you do not specify any mask, the login console function will apply to the entire network.
               
               When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.
               
               Configure a maximum of 40 logon masks, with a total length of 512 characters.
        :param pulumi.Input[builtins.int] login_session_duration: The validity period of the logon session of RAM users.
               Valid values: 1 to 24. Unit: hours.
               Default value: 6.
        :param pulumi.Input[builtins.str] mfa_operation_for_login: MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
               - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
               - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
               - adaptive: Used only during abnormal login.
        :param pulumi.Input[builtins.str] operation_for_risk_login: Whether MFA is verified twice during abnormal logon. Value:
               - autonomous (default): Skip, do not force binding.
               - enforceVerify: Force binding validation.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] verification_types: Means of multi-factor authentication. Value:
               - sms: secure phone.
               - email: Secure mailbox.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if allow_user_to_change_password is not None:
            pulumi.set(__self__, "allow_user_to_change_password", allow_user_to_change_password)
        if allow_user_to_login_with_passkey is not None:
            pulumi.set(__self__, "allow_user_to_login_with_passkey", allow_user_to_login_with_passkey)
        if allow_user_to_manage_access_keys is not None:
            pulumi.set(__self__, "allow_user_to_manage_access_keys", allow_user_to_manage_access_keys)
        if allow_user_to_manage_mfa_devices is not None:
            pulumi.set(__self__, "allow_user_to_manage_mfa_devices", allow_user_to_manage_mfa_devices)
        if allow_user_to_manage_personal_ding_talk is not None:
            pulumi.set(__self__, "allow_user_to_manage_personal_ding_talk", allow_user_to_manage_personal_ding_talk)
        if enable_save_mfa_ticket is not None:
            pulumi.set(__self__, "enable_save_mfa_ticket", enable_save_mfa_ticket)
        if enforce_mfa_for_login is not None:
            pulumi.set(__self__, "enforce_mfa_for_login", enforce_mfa_for_login)
        if login_network_masks is not None:
            pulumi.set(__self__, "login_network_masks", login_network_masks)
        if login_session_duration is not None:
            pulumi.set(__self__, "login_session_duration", login_session_duration)
        if mfa_operation_for_login is not None:
            pulumi.set(__self__, "mfa_operation_for_login", mfa_operation_for_login)
        if operation_for_risk_login is not None:
            pulumi.set(__self__, "operation_for_risk_login", operation_for_risk_login)
        if verification_types is not None:
            pulumi.set(__self__, "verification_types", verification_types)

    @property
    @pulumi.getter(name="allowUserToChangePassword")
    def allow_user_to_change_password(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to manage their own passwords. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_change_password")

    @allow_user_to_change_password.setter
    def allow_user_to_change_password(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_change_password", value)

    @property
    @pulumi.getter(name="allowUserToLoginWithPasskey")
    def allow_user_to_login_with_passkey(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to log on using a passkey. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_login_with_passkey")

    @allow_user_to_login_with_passkey.setter
    def allow_user_to_login_with_passkey(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_login_with_passkey", value)

    @property
    @pulumi.getter(name="allowUserToManageAccessKeys")
    def allow_user_to_manage_access_keys(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to manage their own access keys. Value:
        - true: Allow.
        - false (default): Not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_access_keys")

    @allow_user_to_manage_access_keys.setter
    def allow_user_to_manage_access_keys(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_manage_access_keys", value)

    @property
    @pulumi.getter(name="allowUserToManageMfaDevices")
    def allow_user_to_manage_mfa_devices(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to manage multi-factor authentication devices. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_mfa_devices")

    @allow_user_to_manage_mfa_devices.setter
    def allow_user_to_manage_mfa_devices(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_manage_mfa_devices", value)

    @property
    @pulumi.getter(name="allowUserToManagePersonalDingTalk")
    def allow_user_to_manage_personal_ding_talk(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_personal_ding_talk")

    @allow_user_to_manage_personal_ding_talk.setter
    def allow_user_to_manage_personal_ding_talk(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_manage_personal_ding_talk", value)

    @property
    @pulumi.getter(name="enableSaveMfaTicket")
    def enable_save_mfa_ticket(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
        - true: Allow.
        - false (default): Not allowed.
        """
        return pulumi.get(self, "enable_save_mfa_ticket")

    @enable_save_mfa_ticket.setter
    def enable_save_mfa_ticket(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_save_mfa_ticket", value)

    @property
    @pulumi.getter(name="enforceMfaForLogin")
    def enforce_mfa_for_login(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
        Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        """
        return pulumi.get(self, "enforce_mfa_for_login")

    @enforce_mfa_for_login.setter
    def enforce_mfa_for_login(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enforce_mfa_for_login", value)

    @property
    @pulumi.getter(name="loginNetworkMasks")
    def login_network_masks(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
        - If the mask is specified, RAM users can only log on from the specified IP address.
        - If you do not specify any mask, the login console function will apply to the entire network.

        When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.

        Configure a maximum of 40 logon masks, with a total length of 512 characters.
        """
        return pulumi.get(self, "login_network_masks")

    @login_network_masks.setter
    def login_network_masks(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login_network_masks", value)

    @property
    @pulumi.getter(name="loginSessionDuration")
    def login_session_duration(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The validity period of the logon session of RAM users.
        Valid values: 1 to 24. Unit: hours.
        Default value: 6.
        """
        return pulumi.get(self, "login_session_duration")

    @login_session_duration.setter
    def login_session_duration(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "login_session_duration", value)

    @property
    @pulumi.getter(name="mfaOperationForLogin")
    def mfa_operation_for_login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
        - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
        - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
        - adaptive: Used only during abnormal login.
        """
        return pulumi.get(self, "mfa_operation_for_login")

    @mfa_operation_for_login.setter
    def mfa_operation_for_login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mfa_operation_for_login", value)

    @property
    @pulumi.getter(name="operationForRiskLogin")
    def operation_for_risk_login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether MFA is verified twice during abnormal logon. Value:
        - autonomous (default): Skip, do not force binding.
        - enforceVerify: Force binding validation.
        """
        return pulumi.get(self, "operation_for_risk_login")

    @operation_for_risk_login.setter
    def operation_for_risk_login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "operation_for_risk_login", value)

    @property
    @pulumi.getter(name="verificationTypes")
    def verification_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Means of multi-factor authentication. Value:
        - sms: secure phone.
        - email: Secure mailbox.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "verification_types")

    @verification_types.setter
    def verification_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "verification_types", value)


@pulumi.type_token("alicloud:ram/securityPreference:SecurityPreference")
class SecurityPreference(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_user_to_change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_login_with_passkey: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_access_keys: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_mfa_devices: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_personal_ding_talk: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_save_mfa_ticket: Optional[pulumi.Input[builtins.bool]] = None,
                 enforce_mfa_for_login: Optional[pulumi.Input[builtins.bool]] = None,
                 login_network_masks: Optional[pulumi.Input[builtins.str]] = None,
                 login_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 mfa_operation_for_login: Optional[pulumi.Input[builtins.str]] = None,
                 operation_for_risk_login: Optional[pulumi.Input[builtins.str]] = None,
                 verification_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Import

        RAM Security Preference can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/securityPreference:SecurityPreference example 
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] allow_user_to_change_password: Whether to allow RAM users to manage their own passwords. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_login_with_passkey: Whether to allow RAM users to log on using a passkey. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_access_keys: Whether to allow RAM users to manage their own access keys. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_mfa_devices: Whether to allow RAM users to manage multi-factor authentication devices. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_personal_ding_talk: Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] enable_save_mfa_ticket: Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] enforce_mfa_for_login: Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
               Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        :param pulumi.Input[builtins.str] login_network_masks: The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
               - If the mask is specified, RAM users can only log on from the specified IP address.
               - If you do not specify any mask, the login console function will apply to the entire network.
               
               When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.
               
               Configure a maximum of 40 logon masks, with a total length of 512 characters.
        :param pulumi.Input[builtins.int] login_session_duration: The validity period of the logon session of RAM users.
               Valid values: 1 to 24. Unit: hours.
               Default value: 6.
        :param pulumi.Input[builtins.str] mfa_operation_for_login: MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
               - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
               - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
               - adaptive: Used only during abnormal login.
        :param pulumi.Input[builtins.str] operation_for_risk_login: Whether MFA is verified twice during abnormal logon. Value:
               - autonomous (default): Skip, do not force binding.
               - enforceVerify: Force binding validation.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] verification_types: Means of multi-factor authentication. Value:
               - sms: secure phone.
               - email: Secure mailbox.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SecurityPreferenceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        RAM Security Preference can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/securityPreference:SecurityPreference example 
        ```

        :param str resource_name: The name of the resource.
        :param SecurityPreferenceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityPreferenceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_user_to_change_password: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_login_with_passkey: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_access_keys: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_mfa_devices: Optional[pulumi.Input[builtins.bool]] = None,
                 allow_user_to_manage_personal_ding_talk: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_save_mfa_ticket: Optional[pulumi.Input[builtins.bool]] = None,
                 enforce_mfa_for_login: Optional[pulumi.Input[builtins.bool]] = None,
                 login_network_masks: Optional[pulumi.Input[builtins.str]] = None,
                 login_session_duration: Optional[pulumi.Input[builtins.int]] = None,
                 mfa_operation_for_login: Optional[pulumi.Input[builtins.str]] = None,
                 operation_for_risk_login: Optional[pulumi.Input[builtins.str]] = None,
                 verification_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityPreferenceArgs.__new__(SecurityPreferenceArgs)

            __props__.__dict__["allow_user_to_change_password"] = allow_user_to_change_password
            __props__.__dict__["allow_user_to_login_with_passkey"] = allow_user_to_login_with_passkey
            __props__.__dict__["allow_user_to_manage_access_keys"] = allow_user_to_manage_access_keys
            __props__.__dict__["allow_user_to_manage_mfa_devices"] = allow_user_to_manage_mfa_devices
            __props__.__dict__["allow_user_to_manage_personal_ding_talk"] = allow_user_to_manage_personal_ding_talk
            __props__.__dict__["enable_save_mfa_ticket"] = enable_save_mfa_ticket
            __props__.__dict__["enforce_mfa_for_login"] = enforce_mfa_for_login
            __props__.__dict__["login_network_masks"] = login_network_masks
            __props__.__dict__["login_session_duration"] = login_session_duration
            __props__.__dict__["mfa_operation_for_login"] = mfa_operation_for_login
            __props__.__dict__["operation_for_risk_login"] = operation_for_risk_login
            __props__.__dict__["verification_types"] = verification_types
        super(SecurityPreference, __self__).__init__(
            'alicloud:ram/securityPreference:SecurityPreference',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_user_to_change_password: Optional[pulumi.Input[builtins.bool]] = None,
            allow_user_to_login_with_passkey: Optional[pulumi.Input[builtins.bool]] = None,
            allow_user_to_manage_access_keys: Optional[pulumi.Input[builtins.bool]] = None,
            allow_user_to_manage_mfa_devices: Optional[pulumi.Input[builtins.bool]] = None,
            allow_user_to_manage_personal_ding_talk: Optional[pulumi.Input[builtins.bool]] = None,
            enable_save_mfa_ticket: Optional[pulumi.Input[builtins.bool]] = None,
            enforce_mfa_for_login: Optional[pulumi.Input[builtins.bool]] = None,
            login_network_masks: Optional[pulumi.Input[builtins.str]] = None,
            login_session_duration: Optional[pulumi.Input[builtins.int]] = None,
            mfa_operation_for_login: Optional[pulumi.Input[builtins.str]] = None,
            operation_for_risk_login: Optional[pulumi.Input[builtins.str]] = None,
            verification_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'SecurityPreference':
        """
        Get an existing SecurityPreference resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] allow_user_to_change_password: Whether to allow RAM users to manage their own passwords. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_login_with_passkey: Whether to allow RAM users to log on using a passkey. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_access_keys: Whether to allow RAM users to manage their own access keys. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_mfa_devices: Whether to allow RAM users to manage multi-factor authentication devices. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] allow_user_to_manage_personal_ding_talk: Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
               - true (default): Allowed.
               - false: not allowed.
        :param pulumi.Input[builtins.bool] enable_save_mfa_ticket: Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
               - true: Allow.
               - false (default): Not allowed.
        :param pulumi.Input[builtins.bool] enforce_mfa_for_login: Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
               Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        :param pulumi.Input[builtins.str] login_network_masks: The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
               - If the mask is specified, RAM users can only log on from the specified IP address.
               - If you do not specify any mask, the login console function will apply to the entire network.
               
               When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.
               
               Configure a maximum of 40 logon masks, with a total length of 512 characters.
        :param pulumi.Input[builtins.int] login_session_duration: The validity period of the logon session of RAM users.
               Valid values: 1 to 24. Unit: hours.
               Default value: 6.
        :param pulumi.Input[builtins.str] mfa_operation_for_login: MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
               - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
               - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
               - adaptive: Used only during abnormal login.
        :param pulumi.Input[builtins.str] operation_for_risk_login: Whether MFA is verified twice during abnormal logon. Value:
               - autonomous (default): Skip, do not force binding.
               - enforceVerify: Force binding validation.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] verification_types: Means of multi-factor authentication. Value:
               - sms: secure phone.
               - email: Secure mailbox.
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityPreferenceState.__new__(_SecurityPreferenceState)

        __props__.__dict__["allow_user_to_change_password"] = allow_user_to_change_password
        __props__.__dict__["allow_user_to_login_with_passkey"] = allow_user_to_login_with_passkey
        __props__.__dict__["allow_user_to_manage_access_keys"] = allow_user_to_manage_access_keys
        __props__.__dict__["allow_user_to_manage_mfa_devices"] = allow_user_to_manage_mfa_devices
        __props__.__dict__["allow_user_to_manage_personal_ding_talk"] = allow_user_to_manage_personal_ding_talk
        __props__.__dict__["enable_save_mfa_ticket"] = enable_save_mfa_ticket
        __props__.__dict__["enforce_mfa_for_login"] = enforce_mfa_for_login
        __props__.__dict__["login_network_masks"] = login_network_masks
        __props__.__dict__["login_session_duration"] = login_session_duration
        __props__.__dict__["mfa_operation_for_login"] = mfa_operation_for_login
        __props__.__dict__["operation_for_risk_login"] = operation_for_risk_login
        __props__.__dict__["verification_types"] = verification_types
        return SecurityPreference(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowUserToChangePassword")
    def allow_user_to_change_password(self) -> pulumi.Output[builtins.bool]:
        """
        Whether to allow RAM users to manage their own passwords. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_change_password")

    @property
    @pulumi.getter(name="allowUserToLoginWithPasskey")
    def allow_user_to_login_with_passkey(self) -> pulumi.Output[builtins.bool]:
        """
        Whether to allow RAM users to log on using a passkey. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_login_with_passkey")

    @property
    @pulumi.getter(name="allowUserToManageAccessKeys")
    def allow_user_to_manage_access_keys(self) -> pulumi.Output[builtins.bool]:
        """
        Whether to allow RAM users to manage their own access keys. Value:
        - true: Allow.
        - false (default): Not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_access_keys")

    @property
    @pulumi.getter(name="allowUserToManageMfaDevices")
    def allow_user_to_manage_mfa_devices(self) -> pulumi.Output[builtins.bool]:
        """
        Whether to allow RAM users to manage multi-factor authentication devices. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_mfa_devices")

    @property
    @pulumi.getter(name="allowUserToManagePersonalDingTalk")
    def allow_user_to_manage_personal_ding_talk(self) -> pulumi.Output[builtins.bool]:
        """
        Whether to allow RAM users to independently manage the binding and unbinding of personal DingTalk. Value:
        - true (default): Allowed.
        - false: not allowed.
        """
        return pulumi.get(self, "allow_user_to_manage_personal_ding_talk")

    @property
    @pulumi.getter(name="enableSaveMfaTicket")
    def enable_save_mfa_ticket(self) -> pulumi.Output[builtins.bool]:
        """
        Whether to save the verification status of a RAM user after logging in using multi-factor authentication. The validity period is 7 days. Value:
        - true: Allow.
        - false (default): Not allowed.
        """
        return pulumi.get(self, "enable_save_mfa_ticket")

    @property
    @pulumi.getter(name="enforceMfaForLogin")
    def enforce_mfa_for_login(self) -> pulumi.Output[builtins.bool]:
        """
        Field `enforce_mfa_for_login` has been deprecated from provider version 1.248.0. New field `mfa_operation_for_login` instead. 
        Specifies whether MFA is required for all RAM users when they log on to the Alibaba Cloud Management Console by using usernames and passwords. Valid values: `true` and `false`
        """
        return pulumi.get(self, "enforce_mfa_for_login")

    @property
    @pulumi.getter(name="loginNetworkMasks")
    def login_network_masks(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The login mask. The logon mask determines which IP addresses are affected by the logon console, including password logon and single sign-on (SSO), but API calls made using the access key are not affected.
        - If the mask is specified, RAM users can only log on from the specified IP address.
        - If you do not specify any mask, the login console function will apply to the entire network.

        When you need to configure multiple login masks, use a semicolon (;) to separate them, for example: 192.168.0.0/16;10.0.0.0/8.

        Configure a maximum of 40 logon masks, with a total length of 512 characters.
        """
        return pulumi.get(self, "login_network_masks")

    @property
    @pulumi.getter(name="loginSessionDuration")
    def login_session_duration(self) -> pulumi.Output[builtins.int]:
        """
        The validity period of the logon session of RAM users.
        Valid values: 1 to 24. Unit: hours.
        Default value: 6.
        """
        return pulumi.get(self, "login_session_duration")

    @property
    @pulumi.getter(name="mfaOperationForLogin")
    def mfa_operation_for_login(self) -> pulumi.Output[builtins.str]:
        """
        MFA must be used during logon (replace the original EnforceMFAForLogin parameter, the original parameter is still valid, we recommend that you update it to a new parameter). Value:
        - mandatory: mandatory for all RAM users. The original value of EnforceMFAForLogin is true.
        - independent (default): depends on the independent configuration of each RAM user. The original value of EnforceMFAForLogin is false.
        - adaptive: Used only during abnormal login.
        """
        return pulumi.get(self, "mfa_operation_for_login")

    @property
    @pulumi.getter(name="operationForRiskLogin")
    def operation_for_risk_login(self) -> pulumi.Output[builtins.str]:
        """
        Whether MFA is verified twice during abnormal logon. Value:
        - autonomous (default): Skip, do not force binding.
        - enforceVerify: Force binding validation.
        """
        return pulumi.get(self, "operation_for_risk_login")

    @property
    @pulumi.getter(name="verificationTypes")
    def verification_types(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Means of multi-factor authentication. Value:
        - sms: secure phone.
        - email: Secure mailbox.

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "verification_types")

